@@ -1,6 +1,6 @@
 /**
  * Copyright (C) 2005 Michael Pyne <mpyne@kde.org>
- * Copyright (C) 2014 Arnold Dumas <contact@arnolddumas.com>
+ * Copyright (C) 2014 Arnold Dumas <contact@arnolddumas.fr>
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU General Public License as published by the Free Software
@@ -15,8 +15,8 @@
  * this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef COVERDIALOG_H
-#define COVERDIALOG_H
+#ifndef JUK_COVERDIALOG_H
+#define JUK_COVERDIALOG_H
 
 #include "ui_coverdialogbase.h"
 
@@ -28,7 +28,7 @@ class CoverDialog : public QWidget, public Ui::CoverDialogBase
 {
     Q_OBJECT
 public:
-    CoverDialog(QWidget *parent);
+    explicit CoverDialog(QWidget *parent);
     ~CoverDialog();
 
     virtual void show();
@@ -43,6 +43,6 @@ private slots:
     void removeSelectedCover();
 };
 
-#endif /* COVERDIALOG_H */
+#endif /* JUK_COVERDIALOG_H */
 
 // vim: set et sw=4 tw=0 sta:
