@@ -1,5 +1,6 @@
 /**
  * Copyright (C) 2002-2004 Scott Wheeler <wheeler@kde.org>
+ * Copyright (C) 2021      Michael Pyne  <mpyne@kde.org>
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU General Public License as published by the Free Software
@@ -51,7 +52,6 @@
 #include "treeviewitemplaylist.h"
 #include "actioncollection.h"
 #include "cache.h"
-#include "tracksequencemanager.h"
 #include "tagtransactionmanager.h"
 #include "playermanager.h"
 #include "dbuscollectionproxy.h"
@@ -130,11 +130,11 @@ PlaylistBox::PlaylistBox(PlayerManager *player, QWidget *parent, QStackedWidget
     viewModeAction->setCurrentItem(m_viewModeIndex);
     m_viewModes[m_viewModeIndex]->setShown(true);
 
-    TrackSequenceManager::instance()->setCurrentPlaylist(CollectionList::instance());
     raise(CollectionList::instance());
 
-    m_contextMenu->addAction( viewModeAction );
-    connect(viewModeAction, SIGNAL(triggered(int)), this, SLOT(slotSetViewMode(int)));
+    m_contextMenu->addAction(viewModeAction);
+    connect(viewModeAction, &QAction::triggered,
+            this, &PlaylistBox::slotSetViewMode);
 
     connect(this, SIGNAL(itemSelectionChanged()),
             this, SLOT(slotPlaylistChanged()));
@@ -145,9 +145,14 @@ PlaylistBox::PlaylistBox(PlayerManager *player, QWidget *parent, QStackedWidget
     connect(this, SIGNAL(customContextMenuRequested(QPoint)),
             this, SLOT(slotShowContextMenu(QPoint)));
 
-    TagTransactionManager *tagManager = TagTransactionManager::instance();
-    connect(tagManager, SIGNAL(signalAboutToModifyTags()), SLOT(slotFreezePlaylists()));
-    connect(tagManager, SIGNAL(signalDoneModifyingTags()), SLOT(slotUnfreezePlaylists()));
+    connect(this, &PlaylistBox::signalPlayFile,
+            player, QOverload<const FileHandle &>::of(&PlayerManager::play));
+
+    const auto *tagManager = TagTransactionManager::instance();
+    connect(tagManager, &TagTransactionManager::signalAboutToModifyTags,
+            this,       &PlaylistBox::slotFreezePlaylists);
+    connect(tagManager, &TagTransactionManager::signalDoneModifyingTags,
+            this,       &PlaylistBox::slotUnfreezePlaylists);
 
     setupUpcomingPlaylist();
 
@@ -187,6 +192,12 @@ PlaylistBox::~PlaylistBox()
 
     Cache::savePlaylists(l);
     saveConfig();
+
+    // Some view modes use event filters onto sibling widgets which may be
+    // destroyed before the view mode.
+    // Manually delete the view modes instead.
+    qDeleteAll(m_viewModes);
+    m_viewModes.clear();
 }
 
 void PlaylistBox::raise(Playlist *playlist)
@@ -230,6 +241,12 @@ void PlaylistBox::scanFolders()
     emit startupComplete();
 }
 
+bool PlaylistBox::requestPlaybackFor(const FileHandle &file)
+{
+    emit signalPlayFile(file);
+    return true;
+}
+
 ////////////////////////////////////////////////////////////////////////////////
 // PlaylistBox public slots
 ////////////////////////////////////////////////////////////////////////////////
@@ -459,7 +476,7 @@ void PlaylistBox::setDynamicListsFrozen(bool frozen)
 
 void PlaylistBox::slotSavePlaylists()
 {
-    qCDebug(JUK_LOG) << "Auto-saving playlists.\n";
+    qCDebug(JUK_LOG) << "Auto-saving playlists.";
 
     PlaylistList l;
     CollectionList *collection = CollectionList::instance();
@@ -624,21 +641,9 @@ void PlaylistBox::slotDoubleClicked(QTreeWidgetItem *item)
 {
     if(!item)
         return;
+    auto *playlist = static_cast<Item *>(item)->playlist();
 
-    TrackSequenceManager *manager = TrackSequenceManager::instance();
-    Item *playlistItem = static_cast<Item *>(item);
-
-    manager->setCurrentPlaylist(playlistItem->playlist());
-
-    manager->setCurrent(0); // Reset playback
-    PlaylistItem *next = manager->nextItem(); // Allow manager to choose
-
-    if(next) {
-        emit startFilePlayback(next->file());
-        playlistItem->playlist()->setPlaying(next);
-    }
-    else
-        action("stop")->trigger();
+    playlist->slotBeginPlayback();
 }
 
 void PlaylistBox::slotShowContextMenu(const QPoint &point)
